Changelog
=========

All changes in the package are documented at https://github.com/ckeditor/ckeditor5/blob/master/CHANGELOG.md.

Changes for the past releases are available below.


## 23.0.0 (September 25, 2020)

### Bug fixes

* Fixed crash that happened when an editor with multiple annotations was destroyed.


## 22.0.0 (August 25, 2020)

### Features

* Introduced `sidebar.preventScrollOutOfView` configuration option that prevents sidebar items from being moved out of sight (above the sidebar top edge).

### Other

* Changed annotations positioning algorithms.


## 21.0.0 (July 24, 2020)

### BREAKING CHANGES

* The comments feature now uses the recently introduced marker-to-data conversion. This means that comment markers included in the document data returned from the editor will be different than before. The change is backward compatible with regards to old documents that you have already saved in your database. These documents will be correctly processed by the editor, however, upon saving, the document data will be returned in the new format.

### Bug fixes

* Passing `Rect` or a callback returning `Rect` as an annotation target should work now correctly.

### Other changes

* Switched from marker-to-element conversion to marker-to-data conversion.


## 20.0.1 (June 26, 2020)

### Features

* Introduced support for multi-range comments (multi-cell comments in tables).


### Bug fixes

* Incorrect comment was activated after creating a second comment on the same element or range.


## 19.0.2 (May 25, 2020)

Internal changes only (updated dependencies, documentation, etc.).


## 19.0.1 (April 30, 2020)

### BREAKING CHANGES

* `AnnotationView#active` was renamed to `#isActive`.
* `AnnotationView#hasChanges` was renamed to `#isDirty`.
* Due to changes in how comments are loaded for suggestions, comments now need to be loaded before suggestions in the ["load and save" integration](https://ckeditor.com/docs/ckeditor5/latest/features/collaboration/comments/comments-integration.html#a-simple-load-and-save-integration) type (non-adapter integration).

### Features

* Introduced customizable comment views.
* Localized the UI for comments.

### Bug fixes

* Improved logic that activates balloon annotations.
* Resolved a race condition issue happening when fetching comment data and causing an editor crash.

### Other changes

* Removed the `Comments` plugin API.


## 18.0.0 (March 19, 2020)

### Features

* Introduced `skipEmpty` parameter in `CommentsRepository#getCommentThreads()`.

### Bug fixes

* Fixed contextual balloon glitches happening when switching from inline annotations to sidebar UI while displaying a comment.
* Fixed editor crashing in some scenarios involving track changes adapter during initial data load.
* Fixed incorrectly highlighted suggestions for table row/column insertion and deletion.
* Fixed a bug causing new comments to be added with "Invalid date."
* Comment threads for suggestions will now be correctly returned by `CommentsRepository#getCommentThreads()`.


## 17.0.0 (February 20, 2020)

### BREAKING CHANGES

* The following commands were removed:
  * `addComment`,
  * `removeComment`,
  * `removeCommentThread`,
  * `updateComment`.

  The only editor command used by the comments feature is `addCommentThread`. Now, it is the responsibility of `CommentsRepository` to operate on comments. If your integration extended the removed commands, you should now integrate with the `CommentsRepository` API.
* The previous API available for the `Comments` plugin was deprecated and will be removed in the next release. The `CommentsRepository` API should be used instead.
* The comments feature now expects the `config.collaboration.channelId` configuration parameter. The previously used `config.cloudServices.documentId` was deprecated and will be removed in the next release.
* The comments adapter now requires the `removeCommentThread()` method, which should remove the entire comment thread. If you use a custom comments adapter and would like to support comments outside the editor, you will need to provide this method.
* If you use `Context` in your application, context plugins should be added to the context configuration instead of the editor configuration. The following plugins were changed to context plugins:
  * `Annotations`,
  * `CommentsRepository`,
  * `WideSidebar`,
  * `NarrowSidebar`.

### Known issues

* `Comments#getCommentThreads()` and `CommentsRepository#getCommentThreads( { skipNotAttached: true } )` are not returning comment threads added to suggestions. Instead, use `CommentsRepository#getCommentThreads( { skipNotAttached: false } )` and filter comment threads by their ids, comparing them to ids returned by `TrackChanges#getSuggestions()`.

### Features

* Opened the comments feature API. Enabled creating comments on form fields and other DOM elements outside the editor. Please refer to the documentation to learn about all introduced changes.
* Introduced `CommentsRepository` which is a context plugin that handles comments. It introduces the API to operate on comments and can be used outside or without an editor instance. See the documentation to learn more about the new API.
* Annotations became a context plugin and can be used outside or without an editor instance. See the documentation to learn more about the new API.


## 16.0.0 (December 2, 2019)

### Bug fixes

* `SidebarView#minHeight` will now be cleared when the sidebar becomes empty.


## 15.0.1 (October 24, 2019)

Internal changes only (updated dependencies, documentation, etc.).


## 15.0.0 (October 23, 2019)

### Features

* Enabled comments in the title element.
* Introduced the possibility to [provide a custom date-time format](https://ckeditor.com/docs/ckeditor5/latest/features/collaboration/comments/comments.html#custom-date-format) for the comment balloons.

### Bug fixes

* Fixed incorrect button type in the narrow toolbar.

### Other changes

* Improved annotation positioning by using the DOM element position instead of the markers' order.


## 4.0.0 (August 22, 2019)

### Features

* Added the comment ID, the author ID, and the comment thread ID as data attributes to annotation DOM elements.
* Annotations with an unfinished editing process will now be marked in the narrow sidebar.
* Provided an API to enable and disable the "comments-only" mode. The comments-only plugin is now required by default by the comments plugin but needs to be enabled using the [`commentsOnly` configuration option](https://ckeditor.com/docs/ckeditor5/latest/features/collaboration/comments/comments-only-mode.html).

### Bug fixes

* Sidebar items position is now aligned correctly on window resize.
* Prevented item collisions inside the sidebar.
* Safari does not freeze when rejecting a comment thread that was being added.

### Other changes

* Removed crash events and made the code throw a `CKEditorError` instead.

### BREAKING CHANGES

* The comments-only plugin needs to be enabled using the [`commentsOnly` configuration option](https://ckeditor.com/docs/ckeditor5/latest/features/collaboration/comments/comments-only-mode.html).

## 3.2.0 (July 4, 2019)

### Features

* Introduced the [narrow sidebar](https://ckeditor.com/docs/ckeditor5/latest/features/collaboration/comments/comments-display-mode.html#narrow-sidebar) display mode.
* It is now possible to close the annotations balloon on pressing <kbd>Esc</kbd>.

### Bug fixes

* Fixed UI glitches in inline comments panel animation.

### Other changes

* Improved the visibility of the annotation counter in the narrow sidebar.
* Replaced `trim-html` dependencies with an internal implementation.
* Introduced the support for mobile environments: Android and iOS.

## 3.1.0 (June 5, 2019)

### Features

* Introduced inline comments as a separate [display mode](https://ckeditor.com/docs/ckeditor5/latest/features/collaboration/comments/comments-display-mode.html). It is possible to switch between sidebar and inline comments dynamically.
* Introduced the [`comments.editorConfig` configuration option](https://ckeditor.com/docs/ckeditor5/latest/features/collaboration/comments/comments.html#comment-editor-customization) to define a custom configuration for the comment editor.

### Bug fixes

* Prevented comments from overflowing the sidebar element. The sidebar element changes its `min-height` property when comments are added or removed.
* Improved toggling of the collapsed state of comments.


## 3.0.0 (April 4, 2019)

### Features

* Introduced the `editorConfig.commentsOnly` property. Thanks to it, one build can be used in two modes depending on the editor configuration.
* Added support for [multi-root editor](https://github.com/ckeditor/ckeditor5-collaboration-samples/tree/master/multi-root-editor-with-real-time-collaboration).
* Prepared comments to be displayed inside suggestions.
* Introduced a comment length limit. It is not possible to submit a comment longer than 4000 characters.
* Improved getting the marker top offset to be more layout-independent.

### BREAKING CHANGES

* Starting from this release, it is not enough to add the `CommentsOnly` plugin to enable the comments-only mode. The `editorConfig.commentsOnly` configuration option needs to be set to `true`, too.


## 2.0.0 (February 5, 2019)

### Features

* Improvements in the sidebar plugin to support the track changes feature.

### Bug fixes

* Properly display inactive markers inside an active one.
* Refresh an active sidebar item after all editor changes.
* Set the local creation date for the editor comments.

### Other changes

* Improved the difference between an active and inactive state of annotations.
* Aligned `CommentEditor` to changes in the CKEditor&nbsp;5 core, release 12.0.0.
* The `adapter.addComment()` method can now return an object with a `createAt` property to synchronize the comment creation date with the server. See the [documentation](https://ckeditor.com/docs/ckeditor5/latest/features/collaboration/comments/comments-integration.html#comments-api) to learn more.

### BREAKING CHANGES

* Renamed `Comments#getVisibleCommentThreads()` to `Comments#getCommentThreads()` to unify comments and track changes API naming.
* ` Comments#state` was dropped from the API.
* Renamed `author` to `authorId` in the comment JSON format to unify comments and track changes API naming.

## 1.0.1 (December 6, 2018)

### Bug fixes

* Update dependencies versions.

## 1.0.0 (December 6, 2018)

The initialization of this repository. [CKEditor&nbsp;5 comments](https://ckeditor.com/collaboration/comments/) is a plugin that lets you add comments support to any CKEditor&nbsp;5 build. It provides the API to integrate comments with your application (load the comments data from your database and save them to it).

This package is also the base for the comments handling in [real-time collaborative editing](https://www.npmjs.com/package/@ckeditor/ckeditor5-real-time-collaboration).

There is also a new `CommentsOnly` plugin introduced which allows you to turn the editor to the [comments-only mode](https://ckeditor.com/docs/ckeditor5/latest/features/collaboration/comments/comments-only-mode.html), where the users can add comments to the document but are not allowed to edit its content directly.
