/**
 * @license Copyright (c) 2003-2024, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
/**
 * @module comments/comments/ui/view/commentthreadheaderview
 */
import { View, ButtonView } from 'ckeditor5/src/ui.js';
import type { Locale } from 'ckeditor5/src/utils.js';
import type { CommentThread } from '../../commentsrepository.js';
export declare const MAX_CONTENT_LENGTH = 150;
/**
 * A view for the comment thread header.
 */
export default class CommentThreadHeaderView extends View {
    locale: Locale;
    /**
     * Defines whether the context value exists.
     *
     * @observable
     */
    hasContext: boolean;
    /**
     * Context value to display in the header.
     *
     * @observable
     */
    contextValue: string;
    /**
     * Button view for the button which reopen the comment thread.
     */
    reopenButtonView: ButtonView;
    /**
     * @inheritDoc
     */
    constructor(locale: Locale, model: CommentThread);
    /**
     * @inheritDoc
     */
    render(): void;
}
/**
 * Fired when a user performed an action that should lead to reopen the resolved comment thread.
 *
 * @eventName ~CommentThreadHeaderView#reopenCommentThread
 */
export type UIReopenCommentThreadEvent = {
    name: 'reopenCommentThread';
    args: [id: string];
};
